"A narrative is a description of a business process or area under review. Narratives are also known as policies, process narratives, process descriptions, or control guides."
get_project_narratives(
auth,
objective_id = NULL,
narrative_id = NULL,
fields = NULL,
pagesize = 50,
waittime = 0.2
)Highbond authentication credentials, created from setup_highbond
Required if other parameter is blank. May obtain multiple rows.
Required if other parameter is blank. Will get only one row.
OPTIONAL. A character vector each field requested within the project. NULL will default to all fields.
Defaults to 50. Maximum is 100.
Time in seconds to wait between requests.
A tibble of narratives
possible fields: title, description, created_at, updated_at, objective