Highbond authentication credentials, created from setup_highbond
table_id
The table to be downloaded
timezone
Defaults to Sys.timezone(). See OlsonNames() for a list of allowable timezones.
Value
A list containing the contents, table requested and the original response
Details
Table ID can be found in the path of your Result table.
https://<company_name>.results.highbond.com/projects/<COLLECTION_ID>/controls/<ANALYSIS_ID>/control_tests/<TABLE_ID>